==> valgrind-3.3.0.tar.bz2: valgrind-3.3.0/coregrind/m_debuginfo/priv_readxcoff.h <==

/*--------------------------------------------------------------------*/
/*--- Read XCOFF format debug info.               priv_readxcoff.h ---*/
/*--------------------------------------------------------------------*/

/*
   This file is part of Valgrind, a dynamic binary instrumentation
   framework.

   Copyright (C) 2006-2007 OpenWorks LLP
      info@open-works.co.uk

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307, USA.

   The GNU General Public License is contained in the file COPYING.

   Neither the names of the U.S. Department of Energy nor the
   University of California nor the names of its contributors may be
   used to endorse or promote products derived from this software
   without prior written permission.
*/

#ifndef __PRIV_READXCOFF_H
#define __PRIV_READXCOFF_H


/* Read whatever info we can from an XCOFF object file. */
extern
Bool ML_(read_xcoff_debug_info) ( struct _SegInfo* si,
                                  Addr   data_addr,
                                  SSizeT data_len,
                                  Bool   is_mainexe );

#endif /* ndef __PRIV_READXCOFF_H */

/*--------------------------------------------------------------------*/
/*--- end                                                          ---*/
/*--------------------------------------------------------------------*/

==> valgrind-3.4.0.tar.bz2: valgrind-3.4.0/coregrind/m_debuginfo/priv_readxcoff.h <==

/*--------------------------------------------------------------------*/
/*--- Read XCOFF format debug info.               priv_readxcoff.h ---*/
/*--------------------------------------------------------------------*/

/*
   This file is part of Valgrind, a dynamic binary instrumentation
   framework.

   Copyright (C) 2006-2008 OpenWorks LLP
      info@open-works.co.uk

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307, USA.

   The GNU General Public License is contained in the file COPYING.

   Neither the names of the U.S. Department of Energy nor the
   University of California nor the names of its contributors may be
   used to endorse or promote products derived from this software
   without prior written permission.
*/

#ifndef __PRIV_READXCOFF_H
#define __PRIV_READXCOFF_H


/* Read whatever info we can from an XCOFF object file. */
extern
Bool ML_(read_xcoff_debug_info) ( struct _DebugInfo* di,
                                  Bool   is_mainexe );

#endif /* ndef __PRIV_READXCOFF_H */

/*--------------------------------------------------------------------*/
/*--- end                                                          ---*/
/*--------------------------------------------------------------------*/
